#
# spec file for package python-jsbeautifier
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jsbeautifier
Version:        1.15.1
Release:        1.2
Summary:        JavaScript unobfuscator and beautifier
License:        MIT
URL:            https://jsbeautifier.org
Source0:        https://files.pythonhosted.org/packages/source/j/jsbeautifier/jsbeautifier-%{version}.tar.gz
# https://github.com/beautify-web/js-beautify/issues/1674
Source1:        https://raw.githubusercontent.com/beautify-web/js-beautify/master/LICENSE
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-EditorConfig >= 0.12.2
Requires:       python-setuptools
Requires:       python-six >= 1.13.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module EditorConfig >= 0.12.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six >= 1.13.0}
# /SECTION
%python_subpackages

%description
Beautify, unpack or deobfuscate JavaScript. Handles popular online obfuscators.

%prep
%setup -q -n jsbeautifier-%{version}
cp %{SOURCE1} .

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/js-beautify
%{python_expand %fdupes %{buildroot}%{$python_sitelib}}

%check
%pytest jsbeautifier/tests/testindentation.py
%pytest jsbeautifier/tests/generated/tests.py

%post
%python_install_alternative js-beautify

%postun
%python_uninstall_alternative js-beautify

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/js-beautify
%{python_sitelib}/jsbeautifier
%{python_sitelib}/jsbeautifier-%{version}-py*.egg-info

%changelog
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.15.1:
  * angular support
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.14.11:
  * Editor not working https://beautifier.io/ (#2201)
  * Set nodejs minimum to v14 (#2169)
  * Invalid prettification of object with unicode escape character
    as object key (#2159)
  * invalid json being generated with wrap_line_length (#1932)
  * Require nodejs v12 or greater (#2151)
  * CSS insideNonNestedAtRule generic variable (#2147)
  * Update dependencies (#2145)
  * Fix CI build (#2144)
  * Fixed #2133 Theme Toggle on without_codemirror Mode (#2138)
  * use correct variable name (#2135)
  * docs: Fix a few typos (#2127)
  * Add support for new record types (cont.) (#2118)
  * fix - semicolon followed by block statement doesnt have new line (#2117)
  * Fix formatting related to the element (#2114)
  * issue prettifying (function(){code();{code}})() (#1852)
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.14.7
  * Doc: Updates web browser implementation examples (#2107)
  * HTML formatter breaks layout by introducing newlines (#1989)
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.14.6
  * Globs no longer work on Windows in 1.14.5 (#2093)
- Update to v1.14.5
  * Dependency updates and UI tweaks (#2088)
  * Bump terser from 5.12.1 to 5.14.2 (#2084)
  * new layout breaks everything on long lines (#2071)
  * Dark mode (#2057)
- Update to v1.14.4
  * Extra space before !important added (#2056)
  * css format removes space after quoted value (#2051)
  * Add grid-template-areas to NON_SEMICOLON_NEWLINE_PROPERTY list (#2035)
  * CSS formatter removes useful space (#2024)
  * CHANGELOG.md file was wiped out in v1.14.2 (#2022)
  * Fails to recognize Handlebars block with whitespace control, e.g. {{~#if true ~}} (#1988)
  * Support new sass @use syntax (#1976)
  * Do not remove whitespace after number (#1950)
  * html formatter doesn't support handlebars partial blocks (#>) (#1869)
  * in keyword in class method causes indentation problem (#1846)
  * space_after_named_function not working inside an ES6 class (#1622)
  * Restyle website (#1444)
  * improper line concatenation between 'return' and a prefix expression (#1095)
- Update to v1.14.3
  * [LESS] Fixing issues with spacing when an object literal lives inside a mixin (#2017)
  * Overindentation when using "class" as a key in an object (#1838)
  * CSS Grid template formatting is broken when adding track size after line names (#1817)
  * SCSS module system @use problem (#1798)
  * JS "space_in_empty_paren" failing for class methods (#1151)
  * LESS mixins gets formatted strangely (#722)
- Update to v1.14.2
  * Why put npm in dependencies? (#2005)
  * [Bug] Logical assignments in JS are incorrectly beautified (#1991)
- Update to v1.14.1
  * feature request: cmd+enter hotkey for mac users (#1985)
  * Wrong indentation when the last line in a case is a right brace (#1683)
- Update to v1.14.0
  * import.meta appears on newline (#1978)
  * Added buttons to website (#1930)
  * Logical assignment operators; Fix parsing of optional chaining (#1888)
  * Numbers should be allowed to contain underscores (#1836)
  * Use native mkdirSync instead of 'mkdirp' package (#1833)
  * selector_separator_newline adds erroneous newline on @extend SCSS statements (#1799)
- Update to v1.13.13
  * IE11 compatibility failure v>1.13.5 (#1918)
- Update to v1.13.11
  * Support short PHP tags (#1840)
- Update to v1.13.6
  * Fix space-before-conditional: false to work on switch-case statement (#1881)
  * Optional chaining obj?.[expr] (#1801)
- Update to v1.13.1
  * Option 'max_preserve_newlines' not working on beautify_css.js CSS Beautifier (#1863)
  * React Fragment Short Syntax <></> issue (#1854)
  * add viewport meta tag to index.html (#1843)
  * Add basic smarty templating support (#1820)
  * Tagged Template literals (#1244)
- Update to v1.13.0
  * (internal) Refactor python cssbeautifier to reuse jsbeautifier CLI methods (#1832)
  * (internal) Switch from node-static to serve (#1831)
  * Fixed pip install cssbeautifier (#1830)
- Update to v1.12.0
  * Python jsbeautifier fails for special chars (#1809)
  * pip install cssbeautifier fails (#1808)
  * Add expand brace-style option to css beautifier (#1796)
  * Support nullish-coalescing (#1794)
  * Upgrade ga.js to analytics.js (#1777)
  * Newline rule not working with css-like files (#1776)
  * no new line after self closing tag (#1718)
  * HTML format, no break after ? (#1365)
  * Does this extension still supports applying Allman style to CSS? (#1353)
  * Add brace_style option for CSS (#1259)
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 1.11.0
  Closed Issues
  * Please bump mkdirp to fix mkdirp@0.5.1 vulnerability (#1768)
  * Support optional-chaining (#1727)
  * Please support es module (#1706)
  * Support new js proposals: optional-chaining & pipeline-operator (#1530)
* Tue Mar  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10.3:
  * minor fixes
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10.2:
  * Please update CodeMirror Addon (#1695)
  * Nested braces indentation (#223)
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10.1:
  * javascript fails to format when <?php > is first text inside <script> tag (#1687)
  * 414 Request-URI Too Large (#1640)
* Wed May 22 2019 pgajdos@suse.com
- version update to 1.10.0
  * lot of releases, lot of changes, see
    https://github.com/beautify-web/js-beautify/blob/master/CHANGELOG.md
- added sources
  https://github.com/beautify-web/js-beautify/issues/1674
  + LICENSE
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Sep  7 2017 toddrme2178@gmail.com
- initial version
